inv_which: Given an object and a character or integerish vector, return...

Description Usage Arguments Value

Description

Used for '_at' type functions.

Usage

1
inv_which(x, sel)

Arguments

x

lits or atomic vector

sel

A character vector of names or a numeric vector of positions

Value

vector logical of same length as x


biodatacore/biodatacoreUtils documentation built on May 28, 2019, 7:11 p.m.